@@ -9,6 +9,7 @@ import shutil
 import sys
 
 from pandas import DataFrame
+import dask.dataframe as dd
 import jsoncomment as jsonc
 import numpy as np
 import pandasql
@@ -73,6 +74,8 @@ class Database:
             write_mode=config['write_mode'],
             exporters=config['exporters'],
             webhooks=config['webhooks'],
+            dask_enabled=config['dask_enabled'],
+            dask_partitions=config['dask_partitions'],
         )
 
     @staticmethod
@@ -101,6 +104,8 @@ class Database:
         write_mode='copy',            # type: str
         exporters={},                 # type: Dict[str, Any]
         webhooks=[],                  # type: List[Dict]
+        dask_enabled=False,            # type: bool
+        dask_partitions=8,             # type: int
     ):
         # type: (...) -> None
         r'''
@@ -123,6 +128,10 @@ class Database:
                 Default: {}.
             webhooks (list[dict], optional): List of webhooks to call.
                 Default: [].
+            dask_enabled (bool, optional): Whether to enable Dask.
+                Default: False.
+            dask_partitions (int, optional): Number of partitions to use for
+                Dask. Must be 1 or greater. Default: 8.
 
         Raises:
             TypeError: If specifications contains a non-SpecificationBase
@@ -183,6 +192,8 @@ class Database:
             # type: Dict[str, SpecificationBase]
         self._exporters = exporters
         self._webhooks = webhooks
+        self._dask_enabled = dask_enabled
+        self._dask_partitions = dask_partitions
         self.data = None
 
         # needed for testing
@@ -216,7 +227,7 @@ class Database:
             msg = 'Data not initialized. Please call update.'
             raise RuntimeError(msg)
 
-        temp = db_tools._get_data_for_write(
+        temp = db_tools.get_data_for_write(
             self.data, self._root, self._hb_root
         )
         self._logger.info('create: get data', step=1, total=total)
@@ -355,7 +366,7 @@ class Database:
         Returns:
             Database: self.
         '''
-        total = 12
+        total = 3
         self._logger.info('update', step=0, total=total)
 
         exclude_re = '|'.join([self._exclude_regex, 'hidebound/logs'])
@@ -367,41 +378,27 @@ class Database:
         self._logger.info(f'update: parsed {self._root}', step=1, total=total)
 
         if len(data) > 0:
-            db_tools._add_specification(data, self._specifications)
-            self._logger.info('update: add_specification', step=2, total=total)
+            if self._dask_enabled:
+                data = dd.from_pandas(data, npartitions=self._dask_partitions)
+            data = db_tools.add_specification(data, self._specifications)
+            data = db_tools.validate_filepath(data)
+            data = db_tools.add_file_traits(data)
+            data = db_tools.add_relative_path(data, 'filepath', self._root)
+            data = db_tools.add_asset_name(data)
+            data = db_tools.add_asset_path(data)
+            data = db_tools.add_relative_path(data, 'asset_path', self._root)
+            data = db_tools.add_asset_type(data)
+            data = db_tools.add_asset_traits(data)
+            data = db_tools.validate_assets(data)
+            if self._dask_enabled:
+                data = data.compute()
+        self._logger.info('update: generate', step=2, total=total)
 
-            db_tools._validate_filepath(data)
-            self._logger.info('update: validate_filepath', step=3, total=total)
-
-            db_tools._add_file_traits(data)
-            self._logger.info('update: add_file_traits', step=4, total=total)
-
-            db_tools._add_relative_path(data, 'filepath', self._root)
-            self._logger.info('update: add_relative_path', step=5, total=total)
-
-            db_tools._add_asset_name(data)
-            self._logger.info('update: add_asset_name', step=6, total=total)
-
-            db_tools._add_asset_path(data)
-            self._logger.info('update: add_asset_path', step=7, total=total)
-
-            db_tools._add_relative_path(data, 'asset_path', self._root)
-            self._logger.info('update: add_relative_path', step=8, total=total)
-
-            db_tools._add_asset_type(data)
-            self._logger.info('update: add_asset_type', step=9, total=total)
-
-            db_tools._add_asset_traits(data)
-            self._logger.info('update: add_asset_traits', step=10, total=total)
-
-            db_tools._validate_assets(data)
-            self._logger.info('update: validate_assets', step=11, total=total)
-
-        data = db_tools._cleanup(data)
+        data = db_tools.cleanup(data)
         self.data = data
 
-        self._logger.info('update: cleanup', step=12, total=total)
-        self._logger.info('update: complete', step=12, total=total)
+        self._logger.info('update: cleanup', step=3, total=total)
+        self._logger.info('update: complete', step=3, total=total)
         return self
 
     def delete(self):
